struct CacheKey {
kd_available_space: u64,
parent_size: u64,
}Expand description
Space-optimised cache key that packs bits into as small a size as possible
Fields
kd_available_space: u64The initial cached size of the node itself
parent_size: u64The initial cached size of the parent’s node
Implementations
Sourceimpl CacheKey
impl CacheKey
Sourcefn parent_size(&self) -> u64
fn parent_size(&self) -> u64
Return the parent size with the extra bits that encode the requested axis masked out
Sourcefn x_axis_parent_size(&self) -> u64
fn x_axis_parent_size(&self) -> u64
Return the parent size with the extra bits that encode the requested axis masked out And the y-axis value masked out